Stan Math Library: stan/math/prim/scal/fun/inc_beta.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
inc_beta.hpp File Reference
`#include <boost/math/special_functions/beta.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
double | stan::math::inc_beta (const double &a, const double &b, const double &x)

[ Stan Home Page ] © 2011–2016, Stan Development Team.